import React from "react";
import * as d3 from 'd3';

const Bar = ({ data, width, height }: any) => {
    const svgRef = React.useRef<SVGSVGElement>(null);

    React.useEffect(() => {
        const svg = d3.select(svgRef.current);

        // Set up scales
        const xScale = d3
            .scaleBand()
            .domain(data.map((d: any, i: any) => i))
            .range([0, width])
            .padding(0.1);

        const yScale = d3
            .scaleLinear()
            .domain([0, d3.max(data)])
            .range([height, 0]);

        const X = d3
            .axisBottom(xScale)
            .ticks(5);

        const Y = d3
            .axisLeft(yScale)
            .ticks(5);

        svg
            .select('.x-axis')
            .attr('transform', `translate(0, ${height})`)
            .call(X);

        svg
            .select('.y-axis')
            .call(Y);

        // Create bars
        svg
            .selectAll('.bar')
            .data(data)
            .join('rect')
            .attr('class', 'bar')
            .attr('x', (d: any, i: any) => xScale(i))
            .attr('y', (d: any) => yScale(d))
            .attr('width', xScale.bandwidth())
            .attr('height', (d: any) => height - yScale(d));

    }, [data, width, height]);

    return (
        <svg ref={svgRef} width={width} height={height}>
            <g className="x-axis" />
            <g className="y-axis" />
        </svg>
    );
};

export default function BarChart(props: any) {

    return (
        <div>
            <h1>Affichage des données par un diagramme à barre</h1>
            <div style={{ marginLeft: 10, }}>
                <Bar data={props.data} width={props.width} height={props.height} />
            </div>
        </div>
    )
}