import React from "react";
import * as d3 from 'd3';

const Pie = ({ data, width, height }: any) => {
    const svgRef = React.useRef<SVGSVGElement>(null);

    React.useEffect(() => {
        const svg = d3.select(svgRef.current);

        // Set up pie layout
        const pie = d3
            .pie<{
                label: string;
                value: number;
            }>()
            .sort(null)
            .value(d => d.value);

        // Set up arc generator
        const arc: any = d3
            .arc()
            .outerRadius(Math.min(width, height) / 2)
            .innerRadius(0);

        // Set up color scale
        const color = d3.scaleOrdinal(d3.schemeCategory10);

        // Create pie slices
        svg
            .selectAll('.slice')
            .data(pie(data))
            .join('path')
            .attr('class', 'slice')
            .attr('d', arc)
            .attr('fill', d => color(d.data.label));

    }, [data, width, height]);

    return (
        <svg ref={svgRef} width={width} height={height}>
        </svg>
    );
};

export default function PieChart(props: any) {

    return (
        <div>
            <h1>Affichage des données par un diagramme circulaire</h1>
            <div style={{ marginLeft: 10, }}>
                <Pie data={props.data} width={props.width} height={props.height} />
            </div>
        </div>
    )
}