import React from "react";
import * as d3 from 'd3';

const Line = ({ data, width, height }: any) => {
    const svgRef = React.useRef<SVGSVGElement>(null);

    React.useEffect(() => {
        const svg = d3.select(svgRef.current);

        // Set up scales
        const xScale = d3
            .scaleLinear()
            .domain([d3.min(data, (d: any) => d.x), d3.max(data, (d: any) => d.x)])
            .range([0, width]);

        const yScale = d3
            .scaleLinear()
            .domain([d3.min(data, (d: any) => d.y), d3.max(data, (d: any) => d.y)])
            .range([height, 0]);

        // Create line
        const line = d3
            .line()
            .x((d: any) => xScale(d.x))
            .y((d: any) => yScale(d.y));

        const X: any = d3
            .axisBottom(xScale)
            .ticks(5);

        const Y: any = d3
            .axisLeft(yScale)
            .ticks(5);

        svg
            .select('.x-axis')
            .attr('transform', `translate(0, ${height})`)
            .call(X);

        svg
            .select('.y-axis')
            .call(Y);

        svg
            .selectAll('.line')
            .data([data])
            .join('path')
            .attr('class', 'line')
            .attr('d', line);

        // Add circles for data points
        svg
            .selectAll('.point')
            .data(data)
            .join('circle')
            .attr('class', 'point')
            .attr('cx', (d: any) => xScale(d.x))
            .attr('cy', (d: any) => yScale(d.y))
            .attr('r', 5);

    }, [data, width, height]);

    return (
        <svg ref={svgRef} width={width} height={height}>
            <g className="x-axis" />
            <g className="y-axis" />
        </svg>
    );
};

export default function TimeSeries(props: any) {

    return (
        <div>
            <h1>Affichage des données par une série temporelle</h1>
            <div style={{ marginLeft: 10, }}>
                <Line data={props.data} width={props.width} height={props.height} />
            </div>
        </div>
    )
}